*cd "directory"
capture log close
capture log using "Permutation", replace

*-------------------------------------------------------------------------------
/*
TITLE: Permutation tests

DESCRIPTION: Performs permutation tests to calculate p-values, tables 3-5

OBSERVATION: The exact p-values generated by the permutation tests depend on the ordering of observations in the dataset.
In the original code, the permutation tests for the different tables were carried out using the same dataset as in here, 
but in a few of the cases the dataset was sorted differently, so the p-values generated here are slightly different from
the ones in the published version in a few cases. The changes in the p-values are very small and all the original inferences
carry through.

*-------------------------------------------------------------------------------

TITLE: Permutation tests for nonhonors students (Table III)

DESCRIPTION: Runs permutation tests for nonhonors students
*/


clear
set more off
clear matrix
set mem 6000m


*-------------------------------------------------------------------------------
*COLUMN 1 -- yesno on public

use "Main_Data", clear
set seed 1
set matsize 1000
keep if honor == 0

/* Runs permutation test: randomly assigns half the group to a temporary
"treatment" indicator and regresses yesno against indicator. 
Saves coefficients in a matrix.
*/
mat R=J(1000,1,.)
forvalues row=1(1)1000 {
	gen r=runiform()
	xtile temp=r , n(560)
	gen T = (temp<=281)
	xi: reg yesno T, r
	mat R[`row',1]=_b[T]
	drop T temp r
}

svmat R
drop if R1==.

reg yesno public

//Generates p-value from permutation test by comparing with regression coefficient
gen test1=(R1>abs(_b[public]) | R1<-abs(_b[public]))
sum test1
drop R1
drop test1 
*-------------------------------------------------------------------------------
*COLUMN 2 -- yesno on public, student traits

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 0
set more off


mat R=J(1000,1,.)
forvalues row=1(1)1000 {
	gen r=runiform()
	xtile temp=r , n(531)
	gen T = (temp<=264)
	xi: reg yesno T male age hispanic, r
	mat R[`row',1]=_b[T]
	drop T temp r
}

svmat R
drop if R1==.

reg yesno public male age hispanic, r

gen test1= (R1 >= abs(_b[public]) | R1<= -abs(_b[public]))


sum test*
drop R1
drop test1 
*-------------------------------------------------------------------------------
*COLUMN 3 -- yesno on public, student traits, classroom and surveyor effects
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 0
set more off

mat R=J(1000,1,.)
forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(531)
	gen T = (temp<=264)
	xi: reg yesno T male age hispanic i.classroom i.surv, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

reg yesno public male age hispanic i.classroom i.surv, r

gen test1=(R1 >= abs(_b[public]) |R1<= -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------
/*
TITLE: Permutation tests for honors students (Table III)

DESCRIPTION: Runs permutation tests for honors students 
*/



*-------------------------------------------------------------------------------
*COLUMN 4 -- yesno on public
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 1
set more off

/* Runs permutation test: randomly assigns half the group to a temporary
"treatment" indicator and regresses yesno against indicator. 
Saves coefficients in a matrix.
*/
mat R=J(1000,1,.)
forvalues row=1(1)1000 {
	gen r=runiform()
	xtile temp=r , n(265)
	gen T = (temp<=133)
	xi: reg yesno T, r
	mat R[`row',1]=_b[T]
	drop T temp r
}

svmat R
drop if R1==.

reg yesno public

//Generates p-value from permutation test by comparing with regression coefficient
gen test1=(R1>abs(_b[public]) | R1<-abs(_b[public]))
sum test1
drop R1
drop test1 

*-------------------------------------------------------------------------------
*COLUMN 5 -- yesno on public, student traits

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 1
set more off

mat R=J(1000,1,.)
forvalues row=1(1)1000 {
	gen r=runiform()
	xtile temp=r , n(258)
	gen T = (temp<=130)
	xi: reg yesno T male age hispanic, r
	mat R[`row',1]=_b[T]
	drop T temp r
}

svmat R
drop if R1==.

reg yesno public male age hispanic, r

gen test1= (R1 >= abs(_b[public]) | R1<= -abs(_b[public]))
sum test*
drop R1
drop test1 
*-------------------------------------------------------------------------------
*COLUMN 6 -- yesno on public, student traits, classroom and surveyor effects

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 1
set more off

mat R=J(1000,1,.)
forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(258)
	gen T = (temp<=130)
	xi: reg yesno T male age hispanic i.classroom i.surv, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

reg yesno public male age hispanic i.classroom i.surv, r

gen test1=(R1 >= abs(_b[public]) |R1<= -abs(_b[public]))
sum test*
clear
*-------------------------------------------------------------------------------
*-------------------------------------------------------------------------------
/*
TITLE: Permutation tests for table 4 (non-honors)

DESCRIPTION: Runs permutation tests for effect of public treatment on sign-up
decision, controlling for enrolled honors classes
*/
*-------------------------------------------------------------------------------

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off

*-------------------------------------------------------------------------------
*COLUMN 1 - yesno on public, honors classes enrolled 

keep if honor_ap_to>0 & honor_ap_to<4 & honor==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(184)
	gen T = (temp<=92)
	reg yesno T i.honor_ap_tot, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot, r
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 2 - yesno on public, honors classes enrolled, individual covariates
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(176)
	gen T = (temp<=88)
	reg yesno T i.honor_ap_tot male age hispanic, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot male age hispanic, r
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 3 - yesno on public, honors classes enrolled, individual covariates, classroom and surveyor fixed effects

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(176)
	gen T = (temp<=88)
	reg yesno T i.honor_ap_tot male age hispanic i.classroom i.surv, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot male age hispanic, r
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 4 - yesno on public, honors classes enrolled, individual covariates, honors classes enrolled per subject, classroom and surveyor fixed effects
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(176)
	gen T = (temp<=88)
	reg yesno T i.honor_ap_tot male age hispanic total_honor_ms total_honor_sosci i.classroom i.surv, r	
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot male age hispanic total_honor_ms total_honor_sosci i.classroom i.surv, r	
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
/*
TITLE: Permutation tests for table 4 (honors)

DESCRIPTION: Runs permutation tests for effect of public treatment on sign-up
decision, controlling for enrolled honors classes 
*/
*-------------------------------------------------------------------------------


*-------------------------------------------------------------------------------
********** COLUMN 5 - yesno on public, honors classes enrolled ***********

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==1

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(159)
	gen T = (temp<=82)
	reg yesno T i.honor_ap_tot, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot, r
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 6 - yesno on public, honors classes enrolled, individual covariates
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==1

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(155)
	gen T = (temp<=80)
	reg yesno T i.honor_ap_tot male age hispanic, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot male age hispanic, r
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 7 - yesno on public, honors classes enrolled, individual covariates, classroom and surveyor fixed effects
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==1

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(155)
	gen T = (temp<=80)
	reg yesno T i.honor_ap_tot male age hispanic i.classroom i.surv, r
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot male age hispanic, r
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 8 - yesno on public, honors classes enrolled, individual covariates, honors classes enrolled per subject, classroom and surveyor fixed effects
clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor_ap_to>0 & honor_ap_to<4 & honor==1

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(155)
	gen T = (temp<=80)
	reg yesno T i.honor_ap_tot male age hispanic total_honor_ms total_honor_sosci i.classroom i.surv, r	
	mat R[`row',1]=_b[T]
	drop T temp r
	}
}

svmat R
drop if R1==.

quietly{
	reg yesno public i.honor_ap_tot male age hispanic total_honor_ms total_honor_sosci i.classroom i.surv, r	
}

gen test1=(R1> abs(_b[public]) | R1< -abs(_b[public]))
sum test*
clear

*-------------------------------------------------------------------------------
/*
TITLE: Permutation tests for table 5 (non-honors)

DESCRIPTION: Runs permutation tests for effect of public treatment on sign-up
decision by importance of popularity
*/
*-------------------------------------------------------------------------------



*-------------------------------------------------------------------------------
*COLUMN 1 - yesno on important, publicXimportant, publicXnot

clear
set more off
clear matrix
set mem 6000m
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 0
set more off


mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(541)
	gen T = (temp<=271)
	gen TXimportant=T*important
	gen TXnot=T*(1-important)
	xi: reg yesno important TXnot TXimportant, r
	mat R[`row',1]=_b[TXnot]
	mat R[`row',2]=_b[TXimportant]
	drop T TXimportant TXnot temp r
	}
}

svmat R
drop if R1==.
drop if R2==.

gen publicXimportant = public*important
gen publicXnot = public*(1-important)

quietly{
	reg yesno important publicXimportant publicXnot, r
}

gen test1=(R1> abs(_b[publicXnot]) | R1< -abs(_b[publicXnot]))
gen test2=(R2> abs(_b[publicXimportant]) | R2< -abs(_b[publicXimportant]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 2 - yesno on important, publicXimportant, publicXnot, individual covariates

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 0
set more off


mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(521)
	gen T = (temp<=260)
	gen TXimportant=T*important
	gen TXnot=T*(1-important)
	xi: reg yesno important TXnot TXimportant male age hispanic, r
	mat R[`row',1]=_b[TXnot]
	mat R[`row',2]=_b[TXimportant]
	drop T TXimportant TXnot temp r
	}
}

svmat R
drop if R1==.
drop if R2==.

gen publicXimportant = public*important
gen publicXnot = public*(1-important)

quietly{
	reg yesno important publicXimportant publicXnot male age hispanic, r
}

gen test1=(R1> abs(_b[publicXnot]) | R1< -abs(_b[publicXnot]))
gen test2=(R2> abs(_b[publicXimportant]) | R2< -abs(_b[publicXimportant]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 3 - yesno on important, publicXimportant, publicXnot, individual covariates, classroom and surveyor fixed effects

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor == 0
set more off


mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(521)
	gen T = (temp<=260)
	gen TXimportant=T*important
	gen TXnot=T*(1-important)
	xi: reg yesno important TXnot TXimportant male age hispanic i.surv i.classroom, r
	mat R[`row',1]=_b[TXnot]
	mat R[`row',2]=_b[TXimportant]
	drop T TXimportant TXnot temp r
	}
}

svmat R
drop if R1==.
drop if R2==.

gen publicXimportant = public*important
gen publicXnot = public*(1-important)

quietly{
	reg yesno important publicXimportant publicXnot male age hispanic i.surv i.classroom, r
}

gen test1=(R1> abs(_b[publicXnot]) | R1< -abs(_b[publicXnot]))
gen test2=(R2> abs(_b[publicXimportant]) | R2< -abs(_b[publicXimportant]))
sum test*

*-------------------------------------------------------------------------------
/*
TITLE: Permutation tests for table 5 (honors)

DESCRIPTION: Runs permutation tests for effect of public treatment on sign-up
decision by importance of popularity
*/
*-------------------------------------------------------------------------------

clear
set more off
clear matrix
set mem 6000m
set matsize 1000

*-------------------------------------------------------------------------------
*COLUMN 4 - yesno on important, publicXimportant, publicXnot

set seed 1
use "Main_Data", clear
keep if honor == 1


mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(262)
	gen T = (temp<=132)
	gen TXimportant=T*important
	gen TXnot=T*(1-important)
	xi: reg yesno important TXnot TXimportant, r
	mat R[`row',1]=_b[TXnot]
	mat R[`row',2]=_b[TXimportant]
	drop T TXimportant TXnot temp r
	}
}

svmat R
drop if R1==.
drop if R2==.

gen publicXimportant = public*important
gen publicXnot = public*(1-important)

quietly{
	reg yesno important publicXimportant publicXnot, r
}

gen test1=(R1> abs(_b[publicXnot]) | R1< -abs(_b[publicXnot]))
gen test2=(R2> abs(_b[publicXimportant]) | R2< -abs(_b[publicXimportant]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 5 - yesno on important, publicXimportant, publicXnot, individual covariates

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
set more off
keep if honor==1

mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(256)
	gen T = (temp<=129)
	gen TXimportant=T*important
	gen TXnot=T*(1-important)
	xi: reg yesno important TXnot TXimportant male age hispanic, r
	mat R[`row',1]=_b[TXnot]
	mat R[`row',2]=_b[TXimportant]
	drop T TXimportant TXnot temp r
	}
}

svmat R
drop if R1==.
drop if R2==.

gen publicXimportant = public*important
gen publicXnot = public*(1-important)

quietly{
	reg yesno important publicXimportant publicXnot male age hispanic, r
}

gen test1=(R1> abs(_b[publicXnot]) | R1< -abs(_b[publicXnot]))
gen test2=(R2> abs(_b[publicXimportant]) | R2< -abs(_b[publicXimportant]))
sum test*
clear

*-------------------------------------------------------------------------------
*COLUMN 6 - yesno on important, publicXimportant, publicXnot, individual covariates, classroom and surveyor fixed effects

clear matrix
set seed 1
set matsize 1000
use "Main_Data", clear
keep if honor==1
set more off

mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly {
	gen r=runiform()
	xtile temp=r , n(256)
	gen T = (temp<=129)
	gen TXimportant=T*important
	gen TXnot=T*(1-important)
	xi: reg yesno important TXnot TXimportant male age hispanic i.surv i.classroom, r
	mat R[`row',1]=_b[TXnot]
	mat R[`row',2]=_b[TXimportant]
	drop T TXimportant TXnot temp r
	}
}

svmat R
drop if R1==.
drop if R2==.

gen publicXimportant = public*important
gen publicXnot = public*(1-important)

quietly{
	reg yesno important publicXimportant publicXnot male age hispanic i.surv i.classroom, r
}

gen test1=(R1> abs(_b[publicXnot]) | R1< -abs(_b[publicXnot]))
gen test2=(R2> abs(_b[publicXimportant]) | R2< -abs(_b[publicXimportant]))
sum test*

*-------------------------------------------------------------------------------

log close
